@@ -17,7 +17,9 @@ minor.allele.freqs     = "list",       # JFD
 biallelic.structure    = "list",       # SXX
 linkage.disequilibrium = "list",       # Link
 site.FST               = "list",
-missing.freqs          = "list"
+missing.freqs          = "list",
+nuc.diversity.between  = "list",
+D		       = "list" #Patterson's D
 ))
 
 
@@ -32,13 +34,13 @@ setMethod("show", "region.stats",
 cat("-----\n")
  cat("SLOTS:\n")
  cat("-----\n")
- out <- data.frame(Slots=c("nucleotide.diversity","haplotype.diversity","haplotype.counts", "minor.allele.freqs","linkage.disequilibrium","biallelic.structure","site.FST","missing.freqs"),         
+ out <- data.frame(Slots=c("nucleotide.diversity","haplotype.diversity","haplotype.counts", "minor.allele.freqs","linkage.disequilibrium","biallelic.structure","site.FST","missing.freqs","nuc.diversity.between","D"),         
                
 
                 Description=c(
-               " Nucleotide diversity","Haplotype diversity","Haplotype distribution","Minor allele frequencies","Linkage disequilibrium","Shared and fixed polymorphisms","SNP-wise FST","Missing nucleotides"),
+               " Nucleotide diversity","Haplotype diversity","Haplotype distribution","Minor allele frequencies","Linkage disequilibrium","Shared and fixed polymorphisms","SNP-wise FST","Missing nucleotides","dxy","Patterson's D"),
 
-               Module=c("FST","FST","FST","Detail","Linkage","Detail","Detail","count.unknowns"))
+               Module=c("FST","FST","FST","Detail","Linkage","Detail","Detail","count.unknowns","diversity.stats.between","introgression.stats"))
  
               
 
